from .models import ErrorModel
from django.contrib import admin
from .settings import APP_ERROR_USE_DJANGO_ADMIN_SITE

if APP_ERROR_USE_DJANGO_ADMIN_SITE:
    @admin.register(ErrorModel)
    class ErrorModelAdmin(admin.ModelAdmin):
        def has_add_permission(self, request):
            return False

        date_hierarchy = 'last_seen'
        list_display = (
            'host',
            'path',
            'method',
            'exception_name',
            'count',
            'created_on',
            'last_seen',
            'notification_sent',
            'ticket_raised',
        )
        list_filter = (
            'host',
            'notification_sent',
            'ticket_raised',
        )
        search_fields = ('host', 'path', 'exception_name',)
        change_form_template = 'error_tracker/admin/change_form.html'

        def changeform_view(self, request, object_id=None, form_url='', extra_context=None):
            if object_id:
                extra_context = {
                    'obj': ErrorModel.objects.get(pk=object_id)
                }
            return super(ErrorModelAdmin, self).changeform_view(request, object_id=object_id,
                                                                form_url=form_url, extra_context=extra_context)



# Generated by Django 3.1.2 on 2020-10-18 11:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('error_tracker', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='errormodel',
            name='notification_sent',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='errormodel',
            name='ticket_raised',
            field=models.BooleanField(default=False),
        ),
    ]


# -*- coding: utf-8 -*-
#
#    Django error tracker default urls
#
#    :copyright: 2019 Sonu Kumar
#    :license: BSD-3-Clause
#

from django.urls import path
from .views import detail, view_list, delete_exception

app_name = 'error_tracker'
urlpatterns = [
    path('', view_list, name="view_errors"),
    path('<rhash>/delete', delete_exception, name='delete_error'),
    path('<rhash>', detail, name='view_error'),
]



# -*- coding: utf-8 -*-
#
#    Django error tracker template tags and filters
#
#    :copyright: 2019 Sonu Kumar
#    :license: BSD-3-Clause
#

from django import template
import json
from django.utils.safestring import mark_safe

register = template.Library()


@register.filter
def replace_new_line_with_br(value):
    return value.replace("\n", "<br/>")


@register.filter("to_pretty")
def to_pretty(x):
    html = x
    try:
        x = json.loads(x)
    except Exception as e:
        try:
            x = x.replace("'", '"').replace("\\\\", "\\")
            x = json.loads(x)
        except Exception as e:
            pass
        pass
    
    try:
        html = "<pre>{}</pre>".format(
            json.dumps(x, indent=4, sort_keys=True))
    except Exception as e:
        pass

    return mark_safe(html)
